from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import module_pb2 as _module_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateModuleInput(_message.Message):
    __slots__ = ("module",)
    MODULE_FIELD_NUMBER: _ClassVar[int]
    module: _module_pb2.Module
    def __init__(self, module: _Optional[_Union[_module_pb2.Module, _Mapping]] = ...) -> None: ...

class CreateModuleOutput(_message.Message):
    __slots__ = ("module_id",)
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    def __init__(self, module_id: _Optional[str] = ...) -> None: ...

class UpdateModuleInput(_message.Message):
    __slots__ = ("patch", "module_id", "module")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateModuleInput.Patch]
        DRAFT: _ClassVar[UpdateModuleInput.Patch]
        EXTRA: _ClassVar[UpdateModuleInput.Patch]
        NAME: _ClassVar[UpdateModuleInput.Patch]
        IMAGE_URL: _ClassVar[UpdateModuleInput.Patch]
        INDEX: _ClassVar[UpdateModuleInput.Patch]
        DESCRIPTION: _ClassVar[UpdateModuleInput.Patch]
        WEIGHT: _ClassVar[UpdateModuleInput.Patch]
    ALL: UpdateModuleInput.Patch
    DRAFT: UpdateModuleInput.Patch
    EXTRA: UpdateModuleInput.Patch
    NAME: UpdateModuleInput.Patch
    IMAGE_URL: UpdateModuleInput.Patch
    INDEX: UpdateModuleInput.Patch
    DESCRIPTION: UpdateModuleInput.Patch
    WEIGHT: UpdateModuleInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateModuleInput.Patch]
    module_id: str
    module: _module_pb2.Module
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateModuleInput.Patch, str]]] = ..., module_id: _Optional[str] = ..., module: _Optional[_Union[_module_pb2.Module, _Mapping]] = ...) -> None: ...

class UpdateModuleOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteModuleInput(_message.Message):
    __slots__ = ("module_id",)
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    def __init__(self, module_id: _Optional[str] = ...) -> None: ...

class DeleteModuleOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeModuleInput(_message.Message):
    __slots__ = ("module_id", "member_id", "group_id", "extra")
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    member_id: str
    group_id: str
    extra: _containers.RepeatedScalarFieldContainer[_module_pb2.Module.Extra]
    def __init__(self, module_id: _Optional[str] = ..., member_id: _Optional[str] = ..., group_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_module_pb2.Module.Extra, str]]] = ...) -> None: ...

class DescribeModuleOutput(_message.Message):
    __slots__ = ("module",)
    MODULE_FIELD_NUMBER: _ClassVar[int]
    module: _module_pb2.Module
    def __init__(self, module: _Optional[_Union[_module_pb2.Module, _Mapping]] = ...) -> None: ...

class ListModulesInput(_message.Message):
    __slots__ = ("member_id", "group_id", "offset", "size", "search", "filters", "sort", "order", "extra")
    class Sort(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INDEX: _ClassVar[ListModulesInput.Sort]
    INDEX: ListModulesInput.Sort
    class Filter(_message.Message):
        __slots__ = ("draft", "extra", "graded", "weight")
        DRAFT_FIELD_NUMBER: _ClassVar[int]
        EXTRA_FIELD_NUMBER: _ClassVar[int]
        GRADED_FIELD_NUMBER: _ClassVar[int]
        WEIGHT_FIELD_NUMBER: _ClassVar[int]
        draft: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        extra: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        graded: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        weight: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        def __init__(self, draft: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., extra: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., graded: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., weight: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ...) -> None: ...
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    group_id: str
    offset: int
    size: int
    search: str
    filters: ListModulesInput.Filter
    sort: ListModulesInput.Sort
    order: _direction_pb2.Direction
    extra: _containers.RepeatedScalarFieldContainer[_module_pb2.Module.Extra]
    def __init__(self, member_id: _Optional[str] = ..., group_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListModulesInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListModulesInput.Sort, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_module_pb2.Module.Extra, str]]] = ...) -> None: ...

class ListModulesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_module_pb2.Module]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_module_pb2.Module, _Mapping]]] = ...) -> None: ...

class StartModuleInput(_message.Message):
    __slots__ = ("module_id",)
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    def __init__(self, module_id: _Optional[str] = ...) -> None: ...

class StartModuleOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GradeModuleInput(_message.Message):
    __slots__ = ("module_id", "member_id", "grade", "excused")
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    GRADE_FIELD_NUMBER: _ClassVar[int]
    EXCUSED_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    member_id: str
    grade: int
    excused: bool
    def __init__(self, module_id: _Optional[str] = ..., member_id: _Optional[str] = ..., grade: _Optional[int] = ..., excused: bool = ...) -> None: ...

class GradeModuleOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from .printer_connector_http import *
from .printer_service_pb2 import *
from .printer_job_pb2 import *
from .printer_connector_pb2 import *
from .printer_pb2 import *
from .printer_connector_pb2_grpc import *
from .printer_service_http import *



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Address(_message.Message):
    __slots__ = ("name", "phone", "email", "country", "state", "postal_code", "city", "line1", "house_number", "line2", "pickup_location")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PHONE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    POSTAL_CODE_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    LINE1_FIELD_NUMBER: _ClassVar[int]
    HOUSE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    LINE2_FIELD_NUMBER: _ClassVar[int]
    PICKUP_LOCATION_FIELD_NUMBER: _ClassVar[int]
    name: str
    phone: str
    email: str
    country: str
    state: str
    postal_code: str
    city: str
    line1: str
    house_number: str
    line2: str
    pickup_location: str
    def __init__(self, name: _Optional[str] = ..., phone: _Optional[str] = ..., email: _Optional[str] = ..., country: _Optional[str] = ..., state: _Optional[str] = ..., postal_code: _Optional[str] = ..., city: _Optional[str] = ..., line1: _Optional[str] = ..., house_number: _Optional[str] = ..., line2: _Optional[str] = ..., pickup_location: _Optional[str] = ...) -> None: ...



from .ticket_service_http import *
from .registration_service_http import *
from .announcement_service_pb2 import *
from .result_pb2 import *
from .scoreboard_service_http import *
from .registration_service_pb2 import *
from .contest_pb2 import *
from .violation_service_pb2 import *
from .ticket_pb2 import *
from .ticket_service_pb2 import *
from .problem_service_pb2 import *
from .announcement_pb2 import *
from .events_pb2 import *
from .medal_pb2 import *
from .contest_service_http import *
from .submission_service_pb2 import *
from .participant_service_pb2 import *
from .violation_service_http import *
from .activity_pb2 import *
from .scoreboard_service_pb2 import *
from .submission_pb2 import *
from .ticket_reply_pb2 import *
from .passcode_service_http import *
from .problem_service_http import *
from .score_service_http import *
from .violation_pb2 import *
from .score_service_pb2 import *
from .problem_pb2 import *
from .submission_service_http import *
from .score_pb2 import *
from .admission_service_pb2 import *
from .contest_service_pb2 import *
from .participant_service_http import *
from .admission_service_http import *
from .scoreboard_pb2 import *
from .passcode_service_pb2 import *
from .template_pb2 import *
from .announcement_service_http import *
from .participant_pb2 import *



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Problem(_message.Message):
    __slots__ = ("id", "url", "type", "links", "number", "visible", "origin", "title", "content", "topics", "score", "constraints", "acceptance_rate", "submissions_count", "submissions_accepted", "vote", "vote_count", "difficulty")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[Problem.Extra]
        VOTE: _ClassVar[Problem.Extra]
        TITLE: _ClassVar[Problem.Extra]
        CONTENT_VALUE: _ClassVar[Problem.Extra]
        CONTENT_RENDER: _ClassVar[Problem.Extra]
    UNKNOWN_EXTRA: Problem.Extra
    VOTE: Problem.Extra
    TITLE: Problem.Extra
    CONTENT_VALUE: Problem.Extra
    CONTENT_RENDER: Problem.Extra
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TYPE: _ClassVar[Problem.Type]
        PROGRAM: _ClassVar[Problem.Type]
        FUNCTION: _ClassVar[Problem.Type]
        OUTPUT: _ClassVar[Problem.Type]
        SQL: _ClassVar[Problem.Type]
        ML: _ClassVar[Problem.Type]
    UNKNOWN_TYPE: Problem.Type
    PROGRAM: Problem.Type
    FUNCTION: Problem.Type
    OUTPUT: Problem.Type
    SQL: Problem.Type
    ML: Problem.Type
    class Constraints(_message.Message):
        __slots__ = ("time_limit_min", "time_limit_max", "cpu_limit_min", "cpu_limit_max", "memory_limit_min", "memory_limit_max")
        TIME_LIMIT_MIN_FIELD_NUMBER: _ClassVar[int]
        TIME_LIMIT_MAX_FIELD_NUMBER: _ClassVar[int]
        CPU_LIMIT_MIN_FIELD_NUMBER: _ClassVar[int]
        CPU_LIMIT_MAX_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_MIN_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_MAX_FIELD_NUMBER: _ClassVar[int]
        time_limit_min: int
        time_limit_max: int
        cpu_limit_min: int
        cpu_limit_max: int
        memory_limit_min: int
        memory_limit_max: int
        def __init__(self, time_limit_min: _Optional[int] = ..., time_limit_max: _Optional[int] = ..., cpu_limit_min: _Optional[int] = ..., cpu_limit_max: _Optional[int] = ..., memory_limit_min: _Optional[int] = ..., memory_limit_max: _Optional[int] = ...) -> None: ...
    class LinksEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    VISIBLE_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    ACCEPTANCE_RATE_FIELD_NUMBER: _ClassVar[int]
    SUBMISSIONS_COUNT_FIELD_NUMBER: _ClassVar[int]
    SUBMISSIONS_ACCEPTED_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    type: Problem.Type
    links: _containers.ScalarMap[str, str]
    number: int
    visible: bool
    origin: str
    title: str
    content: _content_pb2.Content
    topics: _containers.RepeatedScalarFieldContainer[str]
    score: float
    constraints: Problem.Constraints
    acceptance_rate: float
    submissions_count: int
    submissions_accepted: int
    vote: int
    vote_count: int
    difficulty: int
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., type: _Optional[_Union[Problem.Type, str]] = ..., links: _Optional[_Mapping[str, str]] = ..., number: _Optional[int] = ..., visible: bool = ..., origin: _Optional[str] = ..., title: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., topics: _Optional[_Iterable[str]] = ..., score: _Optional[float] = ..., constraints: _Optional[_Union[Problem.Constraints, _Mapping]] = ..., acceptance_rate: _Optional[float] = ..., submissions_count: _Optional[int] = ..., submissions_accepted: _Optional[int] = ..., vote: _Optional[int] = ..., vote_count: _Optional[int] = ..., difficulty: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/helpdesk/auto_reply.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/helpdesk/auto_reply.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/helpdesk/auto_reply.proto\x12\x0f\x65olymp.helpdesk\x1a\x18\x65olymp/ecm/content.proto\"k\n\tAutoReply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x14 \x01(\t\x12$\n\x07message\x18\x15 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x0e\n\x06labels\x18\x16 \x03(\tB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.auto_reply_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _globals['_AUTOREPLY']._serialized_start=79
  _globals['_AUTOREPLY']._serialized_end=186
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import script_pb2 as _script_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScriptChangedEvent(_message.Message):
    __slots__ = ("problem_id", "before", "after")
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    before: _script_pb2.Script
    after: _script_pb2.Script
    def __init__(self, problem_id: _Optional[str] = ..., before: _Optional[_Union[_script_pb2.Script, _Mapping]] = ..., after: _Optional[_Union[_script_pb2.Script, _Mapping]] = ...) -> None: ...

class CreateScriptInput(_message.Message):
    __slots__ = ("script",)
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    script: _script_pb2.Script
    def __init__(self, script: _Optional[_Union[_script_pb2.Script, _Mapping]] = ...) -> None: ...

class CreateScriptOutput(_message.Message):
    __slots__ = ("script_id",)
    SCRIPT_ID_FIELD_NUMBER: _ClassVar[int]
    script_id: str
    def __init__(self, script_id: _Optional[str] = ...) -> None: ...

class UpdateScriptInput(_message.Message):
    __slots__ = ("patch", "script_id", "script")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateScriptInput.Patch]
        NAME: _ClassVar[UpdateScriptInput.Patch]
        SECRET: _ClassVar[UpdateScriptInput.Patch]
        RUNTIME: _ClassVar[UpdateScriptInput.Patch]
        SOURCE_URL: _ClassVar[UpdateScriptInput.Patch]
        FILES: _ClassVar[UpdateScriptInput.Patch]
    ALL: UpdateScriptInput.Patch
    NAME: UpdateScriptInput.Patch
    SECRET: UpdateScriptInput.Patch
    RUNTIME: UpdateScriptInput.Patch
    SOURCE_URL: UpdateScriptInput.Patch
    FILES: UpdateScriptInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_ID_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateScriptInput.Patch]
    script_id: str
    script: _script_pb2.Script
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateScriptInput.Patch, str]]] = ..., script_id: _Optional[str] = ..., script: _Optional[_Union[_script_pb2.Script, _Mapping]] = ...) -> None: ...

class UpdateScriptOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteScriptInput(_message.Message):
    __slots__ = ("script_id",)
    SCRIPT_ID_FIELD_NUMBER: _ClassVar[int]
    script_id: str
    def __init__(self, script_id: _Optional[str] = ...) -> None: ...

class DeleteScriptOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeScriptInput(_message.Message):
    __slots__ = ("script_id", "version", "extra")
    SCRIPT_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    script_id: str
    version: int
    extra: _containers.RepeatedScalarFieldContainer[_script_pb2.Script.Extra]
    def __init__(self, script_id: _Optional[str] = ..., version: _Optional[int] = ..., extra: _Optional[_Iterable[_Union[_script_pb2.Script.Extra, str]]] = ...) -> None: ...

class DescribeScriptOutput(_message.Message):
    __slots__ = ("script",)
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    script: _script_pb2.Script
    def __init__(self, script: _Optional[_Union[_script_pb2.Script, _Mapping]] = ...) -> None: ...

class ListScriptsInput(_message.Message):
    __slots__ = ("version", "offset", "size", "search", "filters", "sort", "order", "extra")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NAME: _ClassVar[ListScriptsInput.Sortable]
    NAME: ListScriptsInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("id", "name", "runtime")
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        runtime: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., runtime: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    VERSION_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    version: int
    offset: int
    size: int
    search: str
    filters: ListScriptsInput.Filter
    sort: ListScriptsInput.Sortable
    order: _direction_pb2.Direction
    extra: _containers.RepeatedScalarFieldContainer[_script_pb2.Script.Extra]
    def __init__(self, version: _Optional[int] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListScriptsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListScriptsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_script_pb2.Script.Extra, str]]] = ...) -> None: ...

class ListScriptsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_script_pb2.Script]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_script_pb2.Script, _Mapping]]] = ...) -> None: ...

class ExecuteStressCheckInput(_message.Message):
    __slots__ = ("script_name",)
    SCRIPT_NAME_FIELD_NUMBER: _ClassVar[int]
    script_name: str
    def __init__(self, script_name: _Optional[str] = ...) -> None: ...

class ExecuteStressCheckOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/playground/run.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/playground/run.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import usage_pb2 as eolymp_dot_executor_dot_usage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/playground/run.proto\x12\x11\x65olymp.playground\x1a\x1b\x65olymp/executor/usage.proto\"\xed\x03\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x12\n\nsource_url\x18\x0b \x01(\t\x12\x11\n\tinput_url\x18\r \x01(\t\x12-\n\x06status\x18\x14 \x01(\x0e\x32\x1d.eolymp.playground.Run.Status\x12\r\n\x05\x65rror\x18\x15 \x01(\t\x12\x11\n\texit_code\x18\x1e \x01(\r\x12\x0e\n\x06signal\x18\x1f \x01(\r\x12\x17\n\x0fwall_time_usage\x18  \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18! \x01(\r\x12\x14\n\x0cmemory_usage\x18\" \x01(\x04\x12\x36\n\x0eresource_usage\x18# \x01(\x0b\x32\x1e.eolymp.executor.ResourceUsage\x12\x12\n\noutput_url\x18* \x01(\t\"\xad\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x10\n\x0cPROVISIONING\x10\t\x12\x10\n\x0cINITIALIZING\x10\n\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x45XECUTED\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x11\n\rCPU_EXHAUSTED\x10\x05\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x06\x12\t\n\x05\x45RROR\x10\x07\x12\x0b\n\x07\x46\x41ILURE\x10\x08\x42\x37Z5github.com/eolymp/go-sdk/eolymp/playground;playgroundb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.playground.run_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/playground;playground'
  _globals['_RUN']._serialized_start=80
  _globals['_RUN']._serialized_end=573
  _globals['_RUN_STATUS']._serialized_start=400
  _globals['_RUN_STATUS']._serialized_end=573
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.atlas import suggestion_pb2 as _suggestion_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SuggestionChangedEvent(_message.Message):
    __slots__ = ("problem_id", "before", "after")
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    before: _suggestion_pb2.Suggestion
    after: _suggestion_pb2.Suggestion
    def __init__(self, problem_id: _Optional[str] = ..., before: _Optional[_Union[_suggestion_pb2.Suggestion, _Mapping]] = ..., after: _Optional[_Union[_suggestion_pb2.Suggestion, _Mapping]] = ...) -> None: ...

class CreateSuggestionInput(_message.Message):
    __slots__ = ("suggestion",)
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    suggestion: _suggestion_pb2.Suggestion
    def __init__(self, suggestion: _Optional[_Union[_suggestion_pb2.Suggestion, _Mapping]] = ...) -> None: ...

class CreateSuggestionOutput(_message.Message):
    __slots__ = ("suggestion_id",)
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    suggestion_id: str
    def __init__(self, suggestion_id: _Optional[str] = ...) -> None: ...

class UpdateSuggestionInput(_message.Message):
    __slots__ = ("suggestion_id", "suggestion")
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    suggestion_id: str
    suggestion: _suggestion_pb2.Suggestion
    def __init__(self, suggestion_id: _Optional[str] = ..., suggestion: _Optional[_Union[_suggestion_pb2.Suggestion, _Mapping]] = ...) -> None: ...

class UpdateSuggestionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteSuggestionInput(_message.Message):
    __slots__ = ("suggestion_id",)
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    suggestion_id: str
    def __init__(self, suggestion_id: _Optional[str] = ...) -> None: ...

class DeleteSuggestionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ReviewSuggestionInput(_message.Message):
    __slots__ = ("suggestion_id", "status", "comment")
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    suggestion_id: str
    status: _suggestion_pb2.Suggestion.Status
    comment: _content_pb2.Content
    def __init__(self, suggestion_id: _Optional[str] = ..., status: _Optional[_Union[_suggestion_pb2.Suggestion.Status, str]] = ..., comment: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class ReviewSuggestionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ResubmitSuggestionInput(_message.Message):
    __slots__ = ("suggestion_id",)
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    suggestion_id: str
    def __init__(self, suggestion_id: _Optional[str] = ...) -> None: ...

class ResubmitSuggestionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListSuggestionsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "member_id", "status")
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListSuggestionsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListSuggestionsInput.Filter, _Mapping]] = ...) -> None: ...

class ListSuggestionsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_suggestion_pb2.Suggestion]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_suggestion_pb2.Suggestion, _Mapping]]] = ...) -> None: ...

class DescribeSuggestionInput(_message.Message):
    __slots__ = ("suggestion_id",)
    SUGGESTION_ID_FIELD_NUMBER: _ClassVar[int]
    suggestion_id: str
    def __init__(self, suggestion_id: _Optional[str] = ...) -> None: ...

class DescribeSuggestionOutput(_message.Message):
    __slots__ = ("suggestion",)
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    suggestion: _suggestion_pb2.Suggestion
    def __init__(self, suggestion: _Optional[_Union[_suggestion_pb2.Suggestion, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NONE: _ClassVar[Format]
    IOI: _ClassVar[Format]
    ICPC: _ClassVar[Format]
NONE: Format
IOI: Format
ICPC: Format



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.ecm import node_pb2 as _node_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RenderContentInput(_message.Message):
    __slots__ = ("content",)
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    content: _content_pb2.Content
    def __init__(self, content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class RenderContentOutput(_message.Message):
    __slots__ = ("render",)
    RENDER_FIELD_NUMBER: _ClassVar[int]
    render: _node_pb2.Node
    def __init__(self, render: _Optional[_Union[_node_pb2.Node, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/worker/worker_job.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/worker/worker_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/worker/worker_job.proto\x12\reolymp.worker\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5\x05\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12)\n\x06status\x18\x1e \x01(\x0e\x32\x19.eolymp.worker.Job.Status\x12\x10\n\x08progress\x18\x14 \x01(\r\x12\r\n\x05total\x18\x15 \x01(\r\x12.\n\x06inputs\x18\x04 \x03(\x0b\x32\x1e.eolymp.worker.Job.InputsEntry\x12\x30\n\x07outputs\x18\x1f \x03(\x0b\x32\x1f.eolymp.worker.Job.OutputsEntry\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bprogress_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x63omplete_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08logs_url\x18\x64 \x01(\t\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"v\n\x05Patch\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\r\n\tPATCH_ALL\x10\x01\x12\x12\n\x0ePATCH_PROGRESS\x10\x02\x12\x11\n\rPATCH_OUTPUTS\x10\x03\x12\x12\n\x0ePATCH_LOGS_URL\x10\x04\x12\x10\n\x0cPATCH_STATUS\x10\x05\x42/Z-github.com/eolymp/go-sdk/eolymp/worker;workerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.worker.worker_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/worker;worker'
  _globals['_JOB_INPUTSENTRY']._loaded_options = None
  _globals['_JOB_INPUTSENTRY']._serialized_options = b'8\001'
  _globals['_JOB_OUTPUTSENTRY']._loaded_options = None
  _globals['_JOB_OUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_JOB']._serialized_start=83
  _globals['_JOB']._serialized_end=808
  _globals['_JOB_INPUTSENTRY']._serialized_start=521
  _globals['_JOB_INPUTSENTRY']._serialized_end=566
  _globals['_JOB_OUTPUTSENTRY']._serialized_start=568
  _globals['_JOB_OUTPUTSENTRY']._serialized_end=614
  _globals['_JOB_STATUS']._serialized_start=616
  _globals['_JOB_STATUS']._serialized_end=688
  _globals['_JOB_PATCH']._serialized_start=690
  _globals['_JOB_PATCH']._serialized_end=808
# @@protoc_insertion_point(module_scope)
